@@ -54,33 +54,20 @@ class CouchdbkitHandler(object):
 
         # create databases sessions
         for app_name, uri in databases:
-            if isinstance(uri, tuple):
-                # case when you want to specify server uri 
-                # and database name specifically. usefull
-                # when you proxy couchdb on some path 
-                server_part, dbname = uri
-                parts = urlparse.urlsplit(urllib.unquote(server_part))
-            else:
-                parts = urlparse.urlsplit(urllib.unquote(uri))
-                dbname = parts[2].split("/")[1]
-
-            if parts[0] != 'http' and parts[0] != 'https':
-                raise ValueError('Invalid dbstring')
             
-            if "@" in parts[1]:
-                server_parts = parts[1].split('@')
-                if ":" in server_parts[0]:
-                    username, password = server_parts[0].split(":")
+            try:
+                if isinstance(uri, tuple):
+                    # case when you want to specify server uri 
+                    # and database name specifically. usefull
+                    # when you proxy couchdb on some path 
+                    server_uri, dbname = uri
                 else:
-                    username = server_parts[0]
-                    password = ''
-                server_uri = "%s://%s" % (parts[0], server_parts[1])
-            else:
-                server_uri = '%s://%s' % (parts[0], parts[1])
-                username = password = ""
+                    server_uri, dbname = uri.rsplit("/", 1)
+            except ValueError:
+                raise ValueError("couchdb uri [%s:%s] invalid" % (
+                            app_name, uri))
                 
-            res = CouchdbResource(server_uri, timeout=COUCHDB_TIMEOUT,
-                                filters=[bauth])
+            res = CouchdbResource(server_uri, timeout=COUCHDB_TIMEOUT)
             
             server = Server(server_uri, resource_instance=res)
             app_label = app_name.split('.')[-1]
